==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-std-mesh/CellFilter/SundancePositionalCellPredicate.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */


#ifndef SUNDANCE_POSITIONALCELLPREDICATE_H
#define SUNDANCE_POSITIONALCELLPREDICATE_H


#include "SundanceDefs.hpp"
#include "SundanceCellPredicateBase.hpp"

namespace SundanceStdFwk
{


#define CELL_PREDICATE_(name, code) \
  class name : public CellPredicateFunctorBase, \
               public TSFExtended::Handleable<CellPredicateFunctorBase> \
  { \
  public:\
    name() : CellPredicateFunctorBase(#name){;}            \
      virtual ~name(){;}\
      virtual bool operator()(const Point& x) const code \
        GET_RCP(CellPredicateFunctorBase);\
  }


#define CELL_PREDICATE(name, code) CELL_PREDICATE_(name, code);

  using namespace SundanceUtils;
  using namespace SundanceStdMesh;
  using namespace SundanceStdMesh::Internal;
  using namespace Teuchos;


  /** */
  class CellPredicateFunctorBase
  {
  public:
    /** */
    CellPredicateFunctorBase(const string& name="Functor(" + Teuchos::toString(topID()) + ")")
      : name_(name) {;}

    /** */
    virtual ~CellPredicateFunctorBase(){;}

    /** */
    virtual bool operator()(const Point& x) const = 0 ;

    /** */
    virtual string description() const {return name_;}
  private:
    static int& topID() {static int rtn=0; rtn++; return rtn;}
    string name_;
  };

  
  /** 
   * PositionalCellPredicate tests whether the cell's nodes satisfy
   * a condition on their positions.
   */
  class PositionalCellPredicate : public Internal::CellPredicateBase 
  {
  public:
      
    /** Construct with a function of positions */
    PositionalCellPredicate(const RefCountPtr<CellPredicateFunctorBase>& func) 
      : CellPredicateBase(), func_(func) 
    {;}

    /** virtual dtor */
    virtual ~PositionalCellPredicate(){;}
      
    /** Test the predicate on a batch of cells */
    virtual void testBatch(const Array<int>& cellLID,
                           Array<int>& results) const ;

    /** Write to XML */
    virtual XMLObject toXML() const ;

    /** comparison */
    virtual bool lessThan(const CellPredicateBase* other) const ;

    /** */
    virtual string description() const {return func_->description();}

    /* */
    GET_RCP(CellPredicateBase);

  private:
    RefCountPtr<CellPredicateFunctorBase> func_;
  };

}


#endif

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-std-mesh/CellFilter/SundancePositionalCellPredicate.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */


#ifndef SUNDANCE_POSITIONALCELLPREDICATE_H
#define SUNDANCE_POSITIONALCELLPREDICATE_H


#include "SundanceDefs.hpp"
#include "SundanceCellPredicateBase.hpp"

namespace SundanceStdFwk
{


#define NEW_CELL_PREDICATE(name)  \
  class name : public CellPredicateFunctorBase,  \
               public SundanceUtils::Handleable<CellPredicateFunctorBase>  \
  {  \
  public:  \
    name() : CellPredicateFunctorBase(#name) {} \
      virtual ~name() {}  \
      virtual bool operator()(const Point& x) const; \
        GET_RCP(CellPredicateFunctorBase);  \
  }; \
  \
  bool name::operator()(const Point& x) const


#define CELL_PREDICATE_(name, code) \
  class name : public CellPredicateFunctorBase, \
               public SundanceUtils::Handleable<CellPredicateFunctorBase> \
  { \
  public:\
    name() : CellPredicateFunctorBase(#name){;}            \
      virtual ~name(){;}\
      virtual bool operator()(const Point& x) const code \
        GET_RCP(CellPredicateFunctorBase);\
  }


#define CELL_PREDICATE(name, code) CELL_PREDICATE_(name, code);

  using namespace SundanceUtils;
  using namespace SundanceStdMesh;
  using namespace SundanceStdMesh::Internal;
  using namespace Teuchos;


  /** */
  class CellPredicateFunctorBase
  {
  public:
    /** */
    CellPredicateFunctorBase(const string& name="Functor(" + Teuchos::toString(topID()) + ")")
      : name_(name) {;}

    /** */
    virtual ~CellPredicateFunctorBase(){;}

    /** */
    virtual bool operator()(const Point& x) const = 0 ;

    /** */
    virtual string description() const {return name_;}
  private:
    static int& topID() {static int rtn=0; rtn++; return rtn;}
    string name_;
  };

  
  /** 
   * PositionalCellPredicate tests whether the cell's nodes satisfy
   * a condition on their positions.
   */
  class PositionalCellPredicate : public Internal::CellPredicateBase 
  {
  public:
      
    /** Construct with a function of positions */
    PositionalCellPredicate(const RefCountPtr<CellPredicateFunctorBase>& func) 
      : CellPredicateBase(), func_(func) 
    {;}

    /** virtual dtor */
    virtual ~PositionalCellPredicate(){;}
      
    /** Test the predicate on a batch of cells */
    virtual void testBatch(const Array<int>& cellLID,
                           Array<int>& results) const ;

    /** Write to XML */
    virtual XMLObject toXML() const ;

    /** comparison */
    virtual bool lessThan(const CellPredicateBase* other) const ;

    /** */
    virtual string description() const {return func_->description();}

    /* */
    GET_RCP(CellPredicateBase);

  private:
    RefCountPtr<CellPredicateFunctorBase> func_;
  };

}


#endif
